@@ -128,8 +128,7 @@
 	      (setq idx (1+ idx)))
 	    string)))
      (string-as-unibyte . identity)
-     (multibyte-string-p . ignore)
-     )))
+     (multibyte-string-p . ignore))))
 
 (eval-and-compile
   (defalias 'mm-char-or-char-int-p
